package com.abi.qms.platform.controller.wx;

import com.abi.qms.platform.dto.req.ActivationRecordReq;
import com.abi.qms.platform.dto.req.ListQrPackageWxReq;
import com.abi.qms.platform.dto.req.ReplenishActivationReq;
import com.abi.qms.platform.dto.req.WxQrPackageDetailReq;
import com.abi.qms.platform.dto.res.ActivationRecordRes;
import com.abi.qms.platform.dto.res.ListQrPackageWxRes;
import com.abi.qms.platform.dto.res.WxQrPackageDetailRes;
import com.abi.qms.platform.service.QrPackageService;
import com.abi.task.common.api.base.BaseResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author: fangxinjian
 * @date: 2021/06/08 19:05
 * @description: 小程序码包管理
 */
@Slf4j
@RestController
@RequestMapping("wx/qrPackage")
@Api(tags = "码包管理")
public class WxQrPackageController {

    @Autowired
    private QrPackageService qrPackageService;

    @ApiOperation("码包列表")
    @GetMapping("listWxQrPackage")
    public BaseResponse<ListQrPackageWxRes> listWxQrPackage(@Validated ListQrPackageWxReq listQrPackageWxReq) {
        //查询码包列表
        ListQrPackageWxRes result = qrPackageService.listWxQrPackage(listQrPackageWxReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("码包详情")
    @GetMapping("getWxQrPackageDetail")
    public BaseResponse<WxQrPackageDetailRes> getWxQrPackageDetail(@Validated WxQrPackageDetailReq wxQrPackageDetailReq) {
        //查询码包详情
        WxQrPackageDetailRes res = qrPackageService.getWxQrPackageDetail(wxQrPackageDetailReq);
        //包装出参
        return BaseResponse.create(res);
    }

    @ApiOperation("补充激活")
    @PostMapping("replenishActivation")
    public BaseResponse replenishActivation(@RequestBody ReplenishActivationReq replenishActivationReq) {
        //补充激活
        qrPackageService.replenishActivation(replenishActivationReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("激活记录")
    @GetMapping("getActivationRecord")
    public BaseResponse<ActivationRecordRes> getActivationRecord(@Validated ActivationRecordReq activationRecordReq) {
        //补充激活
        ActivationRecordRes res = qrPackageService.getActivationRecord(activationRecordReq);
        //包装出参
        return BaseResponse.create(res);
    }

}
